@@ -33,6 +33,9 @@ if TYPE_CHECKING:
     from ..surveys import Survey
 
 
+from .firecrawl_scenario import FirecrawlRequest
+
+
 class Scenario(Base, UserDict):
     """
     A dictionary-like object that stores key-value pairs for parameterizing questions.
@@ -72,6 +75,8 @@ class Scenario(Base, UserDict):
         >>> os.unlink(data_path) # Clean up temp file
     """
 
+    firecrawl = FirecrawlRequest()
+
     __documentation__ = "https://docs.expectedparrot.com/en/latest/scenarios.html"
 
     def __init__(self, data: Optional[Union[Dict[str, Any], Mapping[str, Any]]] = None, name: Optional[str] = None):
@@ -137,6 +142,7 @@ class Scenario(Base, UserDict):
             raise TypeError(
                 f"Cannot multiply Scenario with {type(scenario_list_or_scenario)}"
             )
+        
 
     def replicate(self, n: int) -> "ScenarioList":
         """Replicate a scenario n times to return a ScenarioList.
